==> wattleflow_workflow-0.0.0.14-py3-none-any.whl: wattleflow/strategies/helper/huggingface.py <==
# Module Name: strategies/copy/huggingface.py
# Author: (wattleflow@outlook.com)
# Copyright: (c) 2022-2024 WattleFlow
# License: Apache 2 Licence
# Description: This modul contains concrete huggingface strategy classes.

import os
from importlib import import_module
from wattleflow.core import IStrategy
from transformers.file_utils import TRANSFORMERS_CACHE

velicina = lambda p: int(os.path.getsize(p) / 1024)
LOG = lambda t: print(f"{t}")


class StrategyCopyHuggingfaceModels(IStrategy):
    def velicina_datoteke(path):
        size = os.path.getsize(path) / 1024
        decimal = int(size - int(size))
        for unit in ["KB", "MB", "GB", "TB"]:
            if size < 1024:
                break
            size /= 1024
        if not int(size) > 0:
            return "0 KB"
        decimal = size - int(size)
        return (
            "{0:.2f} {1}".format(size, unit)
            if decimal > 0.0
            else "{0} {1}".format(int(size), unit)
        )

    def execute(
        self, source_dir: str = TRANSFORMERS_CACHE, destination_dir: str = None
    ):
        if not os.path.exists(source_dir):
            LOG(f"Izvorni direktorij '{source_dir}' ne postoji.")
            return

        if not os.path.exists(destination_dir):
            LOG("Budem kreirao direktorij {}".format(destination_dir))
            os.makedirs(destination_dir)

        for root, dirs, files in os.walk(source_dir):
            relative_path = os.path.relpath(root, source_dir)
            target_dir = os.path.join(destination_dir, relative_path)
            if not os.path.exists(target_dir):
                os.makedirs(target_dir)

            for file in files:
                source_path = os.path.join(root, file)
                target_path = os.path.join(target_dir, file)
                basename = os.path.basename(source_path)
                dirname = os.path.dirname(target_path)

                # prikazi velicinu datoteke
                LOG(
                    'kopiram "{}" [{}]'.format(basename, velicina_datoteke(source_path))
                )
                if os.path.exists(target_path):
                    if os.path.samefile(source_path, target_path):
                        break

                # ako vec postoji ne kopiraj
                shutil.copy2(source_path, target_path)
                LOG(f"Kopirano: {basename} -> {dirname}")

        LOG("Kopiranje završeno.")

==> wattleflow_workflow-0.0.0.19-py3-none-any.whl: wattleflow/strategies/helper/huggingface.py <==
# Module Name: strategies/copy/huggingface.py
# Author: (wattleflow@outlook.com)
# Copyright: (c) 2022-2024 WattleFlow
# License: Apache 2 Licence
# Description: This modul contains concrete huggingface strategy classes.

import os
import logging
import shutil
from wattleflow.core import IStrategy
from transformers.file_utils import TRANSFORMERS_CACHE

size = lambda p: int(os.path.getsize(p) / 1024)

logger = logging.getLogger("[huggingface.helper]")
logger.setLevel(logging.info)
logger.debug(f"Size: {size}")


class StrategyCopyHuggingfaceModels(IStrategy):
    def file_size(path):
        size = os.path.getsize(path) / 1024
        decimal = int(size - int(size))

        for unit in ["KB", "MB", "GB", "TB"]:
            if size < 1024:
                logging.debug("size < 1024")
                break
            size /= 1024

        if not int(size) > 0:
            return "0 KB"

        decimal = size - int(size)

        return (
            "{0:.2f} {1}".format(size, unit)
            if decimal > 0.0
            else "{0} {1}".format(int(size), unit)
        )

    def execute(
        self, source_dir: str = TRANSFORMERS_CACHE, destination_dir: str = None
    ):
        if not os.path.exists(source_dir):
            logger.error(f"Source directory not found: {source_dir}' ne postoji.")
            return

        if not os.path.exists(destination_dir):
            logger.info("Creating directory: {}".format(destination_dir))
            os.makedirs(destination_dir)

        for root, dirs, files in os.walk(source_dir):
            relative_path = os.path.relpath(root, source_dir)
            target_dir = os.path.join(destination_dir, relative_path)

            if not os.path.exists(target_dir):
                os.makedirs(target_dir)

            for file in files:
                source_path = os.path.join(root, file)
                target_path = os.path.join(target_dir, file)
                basename = os.path.basename(source_path)
                dirname = os.path.dirname(target_path)

                logger.info(
                    'Copying "{}" [{}]'.format(basename, self.file_size(source_path))
                )

                if os.path.exists(target_path):
                    if os.path.samefile(source_path, target_path):
                        logger.warning("File exist: {target_path}")
                        break

                shutil.copy2(source_path, target_path)
                logger.info(f"Kopirano: {basename} -> {dirname}")

        logger.info("Copying done.")
